/*
 * This file and its contents are supplied under the terms of the
 * Common Development and Distribution License ("CDDL"), version 1.0.
 * You may only use this file in accordance with the terms of version
 * 1.0 of the CDDL.
 *
 * A full copy of the text of the CDDL should have accompanied this
 * source.  A copy of the CDDL is also available via the Internet at
 * http://www.illumos.org/license/CDDL.
 */

/*
 * Copyright 2012 David Hoeppner.  All rights reserved.
 */

/*
 * This file contains tunable properties for DCCP.
 */
#include <inet/ip.h>
#include <inet/ip6.h>
#include <inet/dccp_impl.h>
#include <sys/sunddi.h>

mod_prop_info_t dccp_propinfo_tbl[] = {
	/* tunable - 0 */
	{ "smallest_nonpriv_port", MOD_PROTO_DCCP,
	    mod_set_uint32, mod_get_uint32,
	    {1024, (32 * 1024), 1024}, {1024} },

	{ "smallest_anon_port", MOD_PROTO_DCCP,
	    mod_set_uint32, mod_get_uint32,
	    {1024, ULP_MAX_PORT, 32*1024}, {32*1024} },

	{ "largest_anon_port", MOD_PROTO_DCCP,
	    mod_set_uint32, mod_get_uint32,
	    {1024, ULP_MAX_PORT, ULP_MAX_PORT}, {ULP_MAX_PORT} },

	{ "_xmit_lowat", MOD_PROTO_DCCP,
	    mod_set_uint32, mod_get_uint32,
	    {0, (1<<30), DCCP_XMIT_LOWATER},
	    {DCCP_XMIT_LOWATER} },

	{ "_debug", MOD_PROTO_DCCP,
	    mod_set_uint32, mod_get_uint32,
	    {0, 10, 0}, {0} },

	{ "_rst_sent_rate_enabled", MOD_PROTO_DCCP,
	    mod_set_boolean, mod_get_boolean,
	    {B_TRUE}, {B_TRUE} },

	{ "_rst_sent_rate", MOD_PROTO_DCCP,
	    mod_set_uint32, mod_get_uint32,
	    {0, UINT32_MAX, 40}, {40} },

	{ "_ip_abort_cinterval", MOD_PROTO_DCCP,
	    mod_set_uint32, mod_get_uint32,
	    {1*SECONDS, UINT32_MAX, 3*MINUTES}, {3*MINUTES} },

	{ "_ip_abort_linterval", MOD_PROTO_DCCP,
	    mod_set_uint32, mod_get_uint32,
	    {1*SECONDS, UINT32_MAX, 3*MINUTES}, {3*MINUTES} },

	{ "_ip_abort_interval", MOD_PROTO_DCCP,
	    mod_set_uint32, mod_get_uint32,
	    {500*MS, UINT32_MAX, 5*MINUTES}, {5*MINUTES} },

	/* tunable - 10 */
	{ "_ip_notify_cinterval", MOD_PROTO_DCCP,
	    mod_set_uint32, mod_get_uint32,
	    {1*SECONDS, UINT32_MAX, 10*SECONDS}, {10*SECONDS} },

	{ "_ip_notify_interval", MOD_PROTO_DCCP,
	    mod_set_uint32, mod_get_uint32,
	    {500*MS, UINT32_MAX, 10*SECONDS}, {10*SECONDS} },

	{ "_keepalive_interval", MOD_PROTO_DCCP,
	    mod_set_uint32, mod_get_uint32,
	    {10*SECONDS, 10*DAYS, 2*HOURS}, {2*HOURS} },

	{ "_keepalive_abort_interval", MOD_PROTO_DCCP,
	    mod_set_uint32, mod_get_uint32,
	    {0, UINT32_MAX, 8*MINUTES}, {8*MINUTES} },

	{ NULL, 0, NULL, NULL, {0}, {0} }
};

int dccp_propinfo_count = A_CNT(dccp_propinfo_tbl);
